@@ -1,8 +1,8 @@
+
 import logging
 
-from libtaxii.constants import CB_STIX_XML_111
-
 from cabby.entities import ContentBinding
+from cabby.constants import CB_STIX_XML_111
 
 from .commons import run_client, get_basic_arg_parser
 
@@ -10,11 +10,28 @@ log = logging.getLogger(__name__)
 
 DEFAULT_BINDING = CB_STIX_XML_111
 
+
 def extend_arguments(parser):
-    parser.add_argument("-f", "--content-file", dest="content_file", help="file with the content to send", required=True)
-    parser.add_argument("--binding", dest="binding", default=DEFAULT_BINDING, help="content binding")
-    parser.add_argument("--subtype", dest="subtypes", action='append', help="the subtype of the content binding")
-    parser.add_argument("--dest", dest="collections", action='append', help="names of the destination collections")
+
+    parser.add_argument(
+        "-f", "--content-file", dest="content_file",
+        help="file with the content to send",
+        required=True)
+
+    parser.add_argument(
+        "--binding", dest="binding",
+        default=DEFAULT_BINDING,
+        help="content binding")
+
+    parser.add_argument(
+        "--subtype", dest="subtypes",
+        action='append',
+        help="the subtype of the content binding")
+
+    parser.add_argument(
+        "--dest", dest="collections",
+        action='append',
+        help="names of the destination collections")
 
     return parser
 
@@ -33,9 +50,8 @@ def _runner(client, path, args):
 
     client.push(content, binding, collection_names=args.collections, uri=path)
 
-    log.info("Content pushed")
+    log.info("Content block successfully pushed")
 
 
 def push_content():
     run_client(extend_arguments(get_basic_arg_parser()), _runner)
-
